import React, { Children, cloneElement, isValidElement } from 'react';
import { Line } from './components/Line';
/**

AuraBeamAnnotator component.
The Annotator defines the positioning and color of its children components.
@component
@param {Object} props - The component props.
@param {ReactNode} props.children - The children nodes.
@param {string} props.positioning - The positioning of the component ('left' or 'right').
@param {Color} props.color - The color of the component.
@returns {JSX.Element} The rendered AuraBeamAnnotator component.
*/
export const AuraBeamAnnotator = ({ color = "white", positioning = "left", children }) => {
    const right = positioning === 'right';
    return (React.createElement("div", { className: `relative flex flex-col ${right ? 'items-end' : 'items-start'}` },
        React.createElement(Line, { color: color, right: right }),
        children &&
            Children.map(children, child => {
                if (isValidElement(child)) {
                    return cloneElement(child, { color: color, positioning: positioning });
                }
                return null;
            })));
};
//# sourceMappingURL=AuraBeamAnnotator.js.map