import React from 'react';
import { Line } from './components/Line';
/**
 * Renders the body of the AuraBeam component.
 * The body is the main content of the AuraBeam.
 *
 * @component
 * @param {AuraBeamBodyProps} props - The props for the AuraBeamBody component.
 * @param {ReactNode} props.children - The content to be rendered inside the AuraBeamBody component.
 * @param {string} [props.positioning="left"] - The positioning of the AuraBeamBody component. Can be "left" or "right".
 * @param {Color} [props.color="white"] - The color of the AuraBeamBody component.
 * @returns {JSX.Element} The rendered AuraBeamBody component.
 */
export const AuraBeamBody = ({ children, positioning = "left", color = "white" }) => {
    const right = positioning === 'right';
    return (React.createElement("div", { className: "mt-[-0.5px] pb-16 mb-[-0.5px] relative" },
        React.createElement(Line, { color: color, right: right }),
        React.createElement("div", { className: `mt-4 drop-shadow-none ${!right ? "ml-14" : "mr-14 text-right"}` }, children)));
};
//# sourceMappingURL=AuraBeamBody.js.map