import React from 'react';
import { PrimaryTitle } from './components/PrimaryTitle';
import { SecondaryTitle } from './components/SecondaryTitle';
/**
 * Renders the title component for the AuraBeam.
 * The title is the main heading of the AuraBeam.
 *
 * @component
 * @param {AuraBeamTitleProps} props - The props for the AuraBeamTitle component.
 * @param {string} props.title - The title text.
 * @param {string} [props.type="primary"] - The type of the title (primary or secondary).
 * @param {Color} [props.color="white"] - The color of the title.
 * @param {string} [props.positioning="left"] - The positioning of the title (left or right).
 * @returns {JSX.Element} The rendered AuraBeamTitle component.
 */
export const AuraBeamTitle = ({ title, type = "primary", color = "white", positioning = "left" }) => {
    const right = positioning === 'right';
    const primary = type === "primary";
    return (React.createElement("div", { className: "relative flex items-center gap-2" }, primary ?
        React.createElement(PrimaryTitle, { text: title, color: color, right: right })
        :
            React.createElement(SecondaryTitle, { text: title, color: color, right: right })));
};
//# sourceMappingURL=AuraBeamTitle.js.map